@@ -1,6 +1,8 @@
 //! Parser components.
-pub use self::base::{TakeOpt, DEFAULT_PREFIX};
-pub use self::error::PError;
+pub use self::{
+    base::{TakeOpt, DEFAULT_PREFIX},
+    error::PError,
+};
 use crate::*;
 use alloc::{string::String, vec};
 use ritelinked::LinkedHashMap;
@@ -25,7 +27,7 @@ macro_rules! err {
 /// A simple example for parsing YAML only:
 ///
 /// ```
-/// use yaml_peg::{parser::Parser, node};
+/// use yaml_peg::{node, parser::Parser};
 ///
 /// let n = Parser::new(b"true").parse().unwrap();
 /// assert_eq!(n, vec![node!(true)]);
