@@ -1,4 +1,5 @@
-use serde::Deserialize;
+use alloc::string::{String, ToString};
+use serde::{Deserialize, Serialize};
 
 /// A type that can deserialize from any data to string type.
 ///
@@ -22,7 +23,7 @@ use serde::Deserialize;
 /// assert_eq!("20", value.width.to_string());
 /// assert_eq!("20%", percent.width.to_string());
 /// ```
-#[derive(Deserialize, Debug, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, PartialEq)]
 #[serde(untagged)]
 pub enum Stringify {
     /// Boolean value.
@@ -46,3 +47,9 @@ impl ToString for Stringify {
         }
     }
 }
+
+impl Default for Stringify {
+    fn default() -> Self {
+        Self::Str(String::new())
+    }
+}
